package datasets

var PresetMapFileNames = map[string]string{
	"china":       "china",
	"world":       "world",
	"广东":          "guangdong",
	"安徽":          "anhui",
	"福建":          "fujian",
	"甘肃":          "gansu",
	"广西":          "guangxi",
	"贵州":          "guizhou",
	"海南":          "hainan",
	"河北":          "hebei",
	"黑龙江":         "heilongjiang",
	"河南":          "henan",
	"湖北":          "hubei",
	"湖南":          "hunan",
	"江苏":          "jiangsu",
	"江西":          "jiangxi",
	"吉林":          "jilin",
	"辽宁":          "liaoning",
	"内蒙古":         "neimenggu",
	"宁夏":          "ningxia",
	"青海":          "qinghai",
	"山东":          "shandong",
	"山西":          "shanxi",
	"陕西":          "shanxi1",
	"四川":          "sichuan",
	"台湾":          "taiwan",
	"新疆":          "xinjiang",
	"西藏":          "xizang",
	"云南":          "yunnan",
	"浙江":          "zhejiang",
	"七台河":         "hei1_long2_jiang1_qi1_tai2_he2",
	"万宁":          "hai3_nan2_wan4_ning2",
	"三亚":          "hai3_nan2_san1_ya4",
	"三明":          "fu2_jian4_san1_ming2",
	"三沙":          "hai3_nan2_san1_sha1",
	"三门峡":         "he2_nan2_san1_men2_xia2",
	"上海":          "shanghai",
	"上饶":          "jiang1_xi1_shang4_rao2",
	"东方":          "hai3_nan2_dong1_fang1",
	"东沙群岛":        "guang3_dong1_dong1_sha1_qun2_dao3",
	"东莞":          "guang3_dong1_dong1_guan1",
	"东营":          "shan1_dong1_dong1_ying2",
	"中卫":          "ning2_xia4_zhong1_wei4",
	"中山":          "guang3_dong1_zhong1_shan1",
	"临夏回族自治州":     "gan1_su4_lin2_xia4_hui2_zu2_zi4_zhi4_zhou1",
	"临汾":          "shan1_xi1_lin2_fen2",
	"临沂":          "shan1_dong1_lin2_yi2",
	"临沧":          "yun2_nan2_lin2_cang1",
	"临高县":         "hai3_nan2_lin2_gao1_xian4",
	"丹东":          "liao2_ning2_dan1_dong1",
	"丽水":          "zhe4_jiang1_li4_shui3",
	"丽江":          "yun2_nan2_li4_jiang1",
	"乌兰察布":        "nei4_meng2_gu3_wu1_lan2_cha2_bu4",
	"乌海":          "nei4_meng2_gu3_wu1_hai3",
	"乌鲁木齐":        "xin1_jiang1_wu1_lu3_mu4_qi2",
	"乐东黎族自治县":     "hai3_nan2_le4_dong1_li2_zu2_zi4_zhi4_xian4",
	"乐山":          "si4_chuan1_le4_shan1",
	"九江":          "jiang1_xi1_jiu3_jiang1",
	"云浮":          "guang3_dong1_yun2_fu2",
	"五家渠":         "xin1_jiang1_wu3_jia1_qu2",
	"五指山":         "hai3_nan2_wu3_zhi3_shan1",
	"亳州":          "an1_hui1_bo2_zhou1",
	"仙桃":          "hu2_bei3_xian1_tao2",
	"伊春":          "hei1_long2_jiang1_yi1_chun1",
	"伊犁哈萨克自治州":    "xin1_jiang1_yi1_li2_ha1_sa4_ke4_zi4_zhi4_zhou1",
	"佛山":          "guang3_dong1_fo2_shan1",
	"佳木斯":         "hei1_long2_jiang1_jia1_mu4_si1",
	"保亭黎族苗族自治县":   "hai3_nan2_bao3_ting2_li2_zu2_miao2_zu2_zi4_zhi4_xian4",
	"保定":          "he2_bei3_bao3_ding4",
	"保山":          "yun2_nan2_bao3_shan1",
	"信阳":          "he2_nan2_xin4_yang2",
	"儋州":          "hai3_nan2_dan1_zhou1",
	"克孜勒苏柯尔克孜自治州": "xin1_jiang1_ke4_zi1_le4_su1_ke1_er3_ke4_zi1_zi4_zhi4_zhou1",
	"克拉玛依":        "xin1_jiang1_ke4_la1_ma3_yi1",
	"六安":          "an1_hui1_liu4_an1",
	"六盘水":         "gui4_zhou1_liu4_pan2_shui3",
	"兰州":          "gan1_su4_lan2_zhou1",
	"兴安盟":         "nei4_meng2_gu3_xing1_an1_meng2",
	"内江":          "si4_chuan1_nei4_jiang1",
	"凉山彝族自治州":     "si4_chuan1_liang2_shan1_yi2_zu2_zi4_zhi4_zhou1",
	"包头":          "nei4_meng2_gu3_bao1_tou2",
	"北京":          "beijing",
	"北屯":          "xin1_jiang1_bei3_tun2",
	"北海":          "guang3_xi1_bei3_hai3",
	"十堰":          "hu2_bei3_shi2_yan4",
	"南京":          "jiang1_su1_nan2_jing1",
	"南充":          "si4_chuan1_nan2_chong1",
	"南宁":          "guang3_xi1_nan2_ning2",
	"南平":          "fu2_jian4_nan2_ping2",
	"南昌":          "jiang1_xi1_nan2_chang1",
	"南通":          "jiang1_su1_nan2_tong1",
	"南阳":          "he2_nan2_nan2_yang2",
	"博尔塔拉蒙古自治州":   "xin1_jiang1_bo2_er3_ta3_la1_meng2_gu3_zi4_zhi4_zhou1",
	"厦门":          "fu2_jian4_sha4_men2",
	"双河":          "xin1_jiang1_shuang1_he2",
	"双鸭山":         "hei1_long2_jiang1_shuang1_ya1_shan1",
	"可克达拉":        "xin1_jiang1_ke3_ke4_da2_la1",
	"台州":          "zhe4_jiang1_tai2_zhou1",
	"合肥":          "an1_hui1_he2_fei2",
	"吉安":          "jiang1_xi1_ji2_an1",
	"吉林市":         "ji2_lin2_ji2_lin2",
	"吐鲁番":         "xin1_jiang1_tu3_lu3_fan1",
	"吕梁":          "shan1_xi1_lv3_liang2",
	"吴忠":          "ning2_xia4_wu2_zhong1",
	"周口":          "he2_nan2_zhou1_kou3",
	"呼伦贝尔":        "nei4_meng2_gu3_hu1_lun2_bei4_er3",
	"呼和浩特":        "nei4_meng2_gu3_hu1_he2_hao4_te4",
	"和田地区":        "xin1_jiang1_he2_tian2_di4_qu1",
	"咸宁":          "hu2_bei3_xian2_ning2",
	"咸阳":          "shan3_xi1_xian2_yang2",
	"哈密":          "xin1_jiang1_ha1_mi4",
	"哈尔滨":         "hei1_long2_jiang1_ha1_er3_bin1",
	"唐山":          "he2_bei3_tang2_shan1",
	"商丘":          "he2_nan2_shang1_qiu1",
	"商洛":          "shan3_xi1_shang1_luo4",
	"喀什地区":        "xin1_jiang1_ka1_shi2_di4_qu1",
	"嘉兴":          "zhe4_jiang1_jia1_xing1",
	"嘉峪关":         "gan1_su4_jia1_yu4_guan1",
	"四平":          "ji2_lin2_si4_ping2",
	"固原":          "ning2_xia4_gu4_yuan2",
	"图木舒克":        "xin1_jiang1_tu2_mu4_shu1_ke4",
	"塔城地区":        "xin1_jiang1_ta3_cheng2_di4_qu1",
	"大兴安岭地区":      "hei1_long2_jiang1_da4_xing1_an1_ling2_di4_qu1",
	"大同":          "shan1_xi1_da4_tong2",
	"大庆":          "hei1_long2_jiang1_da4_qing4",
	"大理白族自治州":     "yun2_nan2_da4_li3_bai2_zu2_zi4_zhi4_zhou1",
	"大连":          "liao2_ning2_da4_lian2",
	"天水":          "gan1_su4_tian1_shui3",
	"天津":          "tianjin",
	"天门":          "hu2_bei3_tian1_men2",
	"太原":          "shan1_xi1_tai4_yuan2",
	"威海":          "shan1_dong1_wei1_hai3",
	"娄底":          "hu2_nan2_lou2_di3",
	"孝感":          "hu2_bei3_xiao4_gan3",
	"宁德":          "fu2_jian4_ning2_de2",
	"宁波":          "zhe4_jiang1_ning2_bo1",
	"安庆":          "an1_hui1_an1_qing4",
	"安康":          "shan3_xi1_an1_kang1",
	"安阳":          "he2_nan2_an1_yang2",
	"安顺":          "gui4_zhou1_an1_shun4",
	"定安县":         "hai3_nan2_ding4_an1_xian4",
	"定西":          "gan1_su4_ding4_xi1",
	"宜宾":          "si4_chuan1_yi2_bin1",
	"宜昌":          "hu2_bei3_yi2_chang1",
	"宜春":          "jiang1_xi1_yi2_chun1",
	"宝鸡":          "shan3_xi1_bao3_ji1",
	"宣城":          "an1_hui1_xuan1_cheng2",
	"宿州":          "an1_hui1_su4_zhou1",
	"宿迁":          "jiang1_su1_su4_qian1",
	"屯昌县":         "hai3_nan2_tun2_chang1_xian4",
	"山南":          "xi1_cang2_shan1_nan2",
	"岳阳":          "hu2_nan2_yue4_yang2",
	"崇左":          "guang3_xi1_chong2_zuo3",
	"巴中":          "si4_chuan1_ba1_zhong1",
	"巴彦淖尔":        "nei4_meng2_gu3_ba1_yan4_nao4_er3",
	"巴音郭楞蒙古自治州":   "xin1_jiang1_ba1_yin1_guo1_leng2_meng2_gu3_zi4_zhi4_zhou1",
	"常州":          "jiang1_su1_chang2_zhou1",
	"常德":          "hu2_nan2_chang2_de2",
	"平凉":          "gan1_su4_ping2_liang2",
	"平顶山":         "he2_nan2_ping2_ding3_shan1",
	"广元":          "si4_chuan1_guang3_yuan2",
	"广安":          "si4_chuan1_guang3_an1",
	"广州":          "guang3_dong1_guang3_zhou1",
	"庆阳":          "gan1_su4_qing4_yang2",
	"廊坊":          "he2_bei3_lang2_fang1",
	"延安":          "shan3_xi1_yan2_an1",
	"延边朝鲜族自治州":    "ji2_lin2_yan2_bian1_zhao1_xian1_zu2_zi4_zhi4_zhou1",
	"开封":          "he2_nan2_kai1_feng1",
	"张家口":         "he2_bei3_zhang1_jia1_kou3",
	"张家界":         "hu2_nan2_zhang1_jia1_jie4",
	"张掖":          "gan1_su4_zhang1_ye4",
	"徐州":          "jiang1_su1_xu2_zhou1",
	"德宏傣族景颇族自治州":  "yun2_nan2_de2_hong2_dai3_zu2_jing3_po3_zu2_zi4_zhi4_zhou1",
	"德州":          "shan1_dong1_de2_zhou1",
	"德阳":          "si4_chuan1_de2_yang2",
	"忻州":          "shan1_xi1_xin1_zhou1",
	"怀化":          "hu2_nan2_huai2_hua4",
	"怒江傈僳族自治州":    "yun2_nan2_nu4_jiang1_li4_su4_zu2_zi4_zhi4_zhou1",
	"恩施土家族苗族自治州":  "hu2_bei3_en1_shi1_tu3_jia1_zu2_miao2_zu2_zi4_zhi4_zhou1",
	"惠州":          "guang3_dong1_hui4_zhou1",
	"成都":          "si4_chuan1_cheng2_du1",
	"扬州":          "jiang1_su1_yang2_zhou1",
	"承德":          "he2_bei3_cheng2_de2",
	"抚州":          "jiang1_xi1_fu3_zhou1",
	"抚顺":          "liao2_ning2_fu3_shun4",
	"拉萨":          "xi1_cang2_la1_sa4",
	"揭阳":          "guang3_dong1_jie1_yang2",
	"攀枝花":         "si4_chuan1_pan1_zhi1_hua1",
	"文山壮族苗族自治州":   "yun2_nan2_wen2_shan1_zhuang4_zu2_miao2_zu2_zi4_zhi4_zhou1",
	"文昌":          "hai3_nan2_wen2_chang1",
	"新乡":          "he2_nan2_xin1_xiang1",
	"新余":          "jiang1_xi1_xin1_yu2",
	"无锡":          "jiang1_su1_wu2_xi2",
	"日喀则":         "xi1_cang2_ri4_ka1_ze2",
	"日照":          "shan1_dong1_ri4_zhao4",
	"昆明":          "yun2_nan2_kun1_ming2",
	"昆玉":          "xin1_jiang1_kun1_yu4",
	"昌吉回族自治州":     "xin1_jiang1_chang1_ji2_hui2_zu2_zi4_zhi4_zhou1",
	"昌江黎族自治县":     "hai3_nan2_chang1_jiang1_li2_zu2_zi4_zhi4_xian4",
	"昌都":          "xi1_cang2_chang1_du1",
	"昭通":          "yun2_nan2_zhao1_tong1",
	"晋中":          "shan1_xi1_jin4_zhong1",
	"晋城":          "shan1_xi1_jin4_cheng2",
	"普洱":          "yun2_nan2_pu3_er3",
	"景德镇":         "jiang1_xi1_jing3_de2_zhen4",
	"曲靖":          "yun2_nan2_qu1_jing4",
	"朔州":          "shan1_xi1_shuo4_zhou1",
	"朝阳":          "liao2_ning2_zhao1_yang2",
	"本溪":          "liao2_ning2_ben3_xi1",
	"来宾":          "guang3_xi1_lai2_bin1",
	"杭州":          "zhe4_jiang1_hang2_zhou1",
	"松原":          "ji2_lin2_song1_yuan2",
	"林芝":          "xi1_cang2_lin2_zhi1",
	"果洛藏族自治州":     "qing1_hai3_guo3_luo4_cang2_zu2_zi4_zhi4_zhou1",
	"枣庄":          "shan1_dong1_zao3_zhuang1",
	"柳州":          "guang3_xi1_liu3_zhou1",
	"株洲":          "hu2_nan2_zhu1_zhou1",
	"桂林":          "guang3_xi1_gui4_lin2",
	"梅州":          "guang3_dong1_mei2_zhou1",
	"梧州":          "guang3_xi1_wu2_zhou1",
	"楚雄彝族自治州":     "yun2_nan2_chu3_xiong2_yi2_zu2_zi4_zhi4_zhou1",
	"榆林":          "shan3_xi1_yu2_lin2",
	"武威":          "gan1_su4_wu3_wei1",
	"武汉":          "hu2_bei3_wu3_han4",
	"毕节":          "gui4_zhou1_bi4_jie2",
	"永州":          "hu2_nan2_yong3_zhou1",
	"汉中":          "shan3_xi1_han4_zhong1",
	"汕头":          "guang3_dong1_shan4_tou2",
	"汕尾":          "guang3_dong1_shan4_wei3",
	"江门":          "guang3_dong1_jiang1_men2",
	"池州":          "an1_hui1_chi2_zhou1",
	"沈阳":          "liao2_ning2_shen3_yang2",
	"沧州":          "he2_nan2_cang1_zhou1",
	"河池":          "guang3_xi1_he2_chi2",
	"河源":          "guang3_dong1_he2_yuan2",
	"泉州":          "fu2_jian4_quan2_zhou1",
	"泰安":          "shan1_dong1_tai4_an1",
	"泰州":          "jiang1_su1_tai4_zhou1",
	"泸州":          "si4_chuan1_lu2_zhou1",
	"洛阳":          "he2_nan2_luo4_yang2",
	"济南":          "shan1_dong1_ji4_nan2",
	"济宁":          "shan1_dong1_ji4_ning2",
	"济源":          "he2_nan2_ji4_yuan2",
	"海东":          "qing1_hai3_hai3_dong1",
	"海北藏族自治州":     "qing1_hai3_hai3_bei3_cang2_zu2_zi4_zhi4_zhou1",
	"海南藏族自治州":     "qing1_hai3_hai3_nan2_cang2_zu2_zi4_zhi4_zhou1",
	"海口":          "hai3_nan2_hai3_kou3",
	"海西蒙古族藏族自治州":  "qing1_hai3_hai3_xi1_meng2_gu3_zu2_cang2_zu2_zi4_zhi4_zhou1",
	"淄博":          "shan1_dong1_zi1_bo2",
	"淮北":          "an1_hui1_huai2_bei3",
	"淮南":          "an1_hui1_huai2_nan2",
	"淮安":          "jiang1_su1_huai2_an1",
	"深圳":          "guang3_dong1_shen1_zhen4",
	"清远":          "guang3_dong1_qing1_yuan3",
	"温州":          "zhe4_jiang1_wen1_zhou1",
	"渭南":          "shan3_xi1_wei4_nan2",
	"湖州":          "zhe4_jiang1_hu2_zhou1",
	"湘潭":          "hu2_nan2_xiang1_tan2",
	"湘西土家族苗族自治州":  "hu2_nan2_xiang1_xi1_tu3_jia1_zu2_miao2_zu2_zi4_zhi4_zhou1",
	"湛江":          "guang3_dong1_zhan4_jiang1",
	"滁州":          "an1_hui1_chu2_zhou1",
	"滨州":          "shan1_dong1_bin1_zhou1",
	"漯河":          "he2_nan2_ta4_he2",
	"漳州":          "fu2_jian4_zhang1_zhou1",
	"潍坊":          "shan1_dong1_wei2_fang1",
	"潜江":          "hu2_bei3_qian2_jiang1",
	"潮州":          "guang3_dong1_chao2_zhou1",
	"澄迈县":         "hai3_nan2_cheng2_mai4_xian4",
	"澳门":          "aomen",
	"濮阳":          "he2_nan2_pu2_yang2",
	"烟台":          "shan1_dong1_yan1_tai2",
	"焦作":          "he2_nan2_jiao1_zuo4",
	"牡丹江":         "hei1_long2_jiang1_mu3_dan1_jiang1",
	"玉林":          "guang3_xi1_yu4_lin2",
	"玉树藏族自治州":     "qing1_hai3_yu4_shu4_cang2_zu2_zi4_zhi4_zhou1",
	"玉溪":          "yun2_nan2_yu4_xi1",
	"珠海":          "guang3_dong1_zhu1_hai3",
	"琼中黎族苗族自治县":   "hai3_nan2_qiong2_zhong1_li2_zu2_miao2_zu2_zi4_zhi4_xian4",
	"琼海":          "hai3_nan2_qiong2_hai3",
	"甘南藏族自治州":     "gan1_su4_gan1_nan2_cang2_zu2_zi4_zhi4_zhou1",
	"甘孜藏族自治州":     "si4_chuan1_gan1_zi1_cang2_zu2_zi4_zhi4_zhou1",
	"白城":          "ji2_lin2_bai2_cheng2",
	"白山":          "ji2_lin2_bai2_shan1",
	"白沙黎族自治县":     "hai3_nan2_bai2_sha1_li2_zu2_zi4_zhi4_xian4",
	"白银":          "gan1_su4_bai2_yin2",
	"百色":          "guang3_xi1_bai3_se4",
	"益阳":          "hu2_nan2_yi4_yang2",
	"盐城":          "jiang1_su1_yan2_cheng2",
	"盘锦":          "liao2_ning2_pan2_jin3",
	"眉山":          "si4_chuan1_mei2_shan1",
	"石嘴山":         "ning2_xia4_shi2_zui3_shan1",
	"石家庄":         "he2_bei3_shi2_jia1_zhuang1",
	"石河子":         "xin1_jiang1_shi2_he2_zi3",
	"神农架林区":       "hu2_bei3_shen2_nong2_jia4_lin2_qu1",
	"福州":          "fu2_jian4_fu2_zhou1",
	"秦皇岛":         "he2_bei3_qin2_huang2_dao3",
	"红河哈尼族彝族自治州":  "yun2_nan2_hong2_he2_ha1_ni2_zu2_yi2_zu2_zi4_zhi4_zhou1",
	"绍兴":          "zhe4_jiang1_shao4_xing1",
	"绥化":          "hei1_long2_jiang1_sui1_hua4",
	"绵阳":          "si4_chuan1_mian2_yang2",
	"聊城":          "shan1_dong1_liao2_cheng2",
	"肇庆":          "guang3_dong1_zhao4_qing4",
	"自贡":          "si4_chuan1_zi4_gong4",
	"舟山":          "zhe4_jiang1_zhou1_shan1",
	"芜湖":          "an1_hui1_wu2_hu2",
	"苏州":          "jiang1_su1_su1_zhou1",
	"茂名":          "guang3_dong1_mao4_ming2",
	"荆州":          "hu2_bei3_jing1_zhou1",
	"荆门":          "hu2_bei3_jing1_men2",
	"莆田":          "fu2_jian4_fu3_tian2",
	"莱芜":          "shan1_dong1_lai2_wu2",
	"菏泽":          "shan1_dong1_he2_ze2",
	"萍乡":          "jiang1_xi1_ping2_xiang1",
	"营口":          "liao2_ning2_ying2_kou3",
	"葫芦岛":         "liao2_ning2_hu2_lu2_dao3",
	"蚌埠":          "an1_hui1_bang4_bu4",
	"衡水":          "he2_bei3_heng2_shui3",
	"衡阳":          "hu2_nan2_heng2_yang2",
	"衢州":          "zhe4_jiang1_qu2_zhou1",
	"襄阳":          "hu2_bei3_xiang1_yang2",
	"西双版纳傣族自治州":   "yun2_nan2_xi1_shuang1_ban3_na4_dai3_zu2_zi4_zhi4_zhou1",
	"西宁":          "qing1_hai3_xi1_ning2",
	"西安":          "shan3_xi1_xi1_an1",
	"许昌":          "he2_nan2_xu3_chang1",
	"贵港":          "guang3_xi1_gui4_gang3",
	"贵阳":          "gui4_zhou1_gui4_yang2",
	"贺州":          "guang3_xi1_he4_zhou1",
	"资阳":          "si4_chuan1_zi1_yang2",
	"赣州":          "jiang1_xi1_gan4_zhou1",
	"赤峰":          "nei4_meng2_gu3_chi4_feng1",
	"辽源":          "ji2_lin2_liao2_yuan2",
	"辽阳":          "liao2_ning2_liao2_yang2",
	"达州":          "si4_chuan1_da2_zhou1",
	"运城":          "shan1_xi1_yun4_cheng2",
	"连云港":         "jiang1_su1_lian2_yun2_gang3",
	"迪庆藏族自治州":     "yun2_nan2_di2_qing4_cang2_zu2_zi4_zhi4_zhou1",
	"通化":          "ji2_lin2_tong1_hua4",
	"通辽":          "nei4_meng2_gu3_tong1_liao2",
	"遂宁":          "si4_chuan1_sui4_ning2",
	"遵义":          "gui4_zhou1_zun1_yi4",
	"邢台":          "he2_bei3_xing2_tai2",
	"那曲地区":        "xi1_cang2_na4_qu1_di4_qu1",
	"邯郸":          "he2_bei3_han2_dan1",
	"邵阳":          "hu2_nan2_shao4_yang2",
	"郑州":          "he2_nan2_zheng4_zhou1",
	"郴州":          "hu2_nan2_chen1_zhou1",
	"鄂尔多斯":        "nei4_meng2_gu3_e4_er3_duo1_si1",
	"鄂州":          "hu2_bei3_e4_zhou1",
	"酒泉":          "gan1_su4_jiu3_quan2",
	"重庆":          "chongqing",
	"金华":          "zhe4_jiang1_jin1_hua2",
	"金昌":          "gan1_su4_jin1_chang1",
	"钦州":          "guang3_xi1_qin1_zhou1",
	"铁岭":          "liao2_ning2_tie3_ling2",
	"铁门关":         "xin1_jiang1_tie3_men2_guan1",
	"铜仁":          "gui4_zhou1_tong2_ren2",
	"铜川":          "shan3_xi1_tong2_chuan1",
	"铜陵":          "an1_hui1_tong2_ling2",
	"银川":          "ning2_xia4_yin2_chuan1",
	"锡林郭勒盟":       "nei4_meng2_gu3_xi2_lin2_guo1_le4_meng2",
	"锦州":          "liao2_ning2_jin3_zhou1",
	"镇江":          "jiang1_su1_zhen4_jiang1",
	"长春":          "ji2_lin2_chang2_chun1",
	"长沙":          "hu2_nan2_chang2_sha1",
	"长治":          "shan1_xi1_chang2_zhi4",
	"阜新":          "liao2_ning2_fu4_xin1",
	"阜阳":          "an1_hui1_fu4_yang2",
	"防城港":         "guang3_xi1_fang2_cheng2_gang3",
	"阳江":          "guang3_dong1_yang2_jiang1",
	"阳泉":          "shan1_xi1_yang2_quan2",
	"阿克苏地区":       "xin1_jiang1_a1_ke4_su1_di4_qu1",
	"阿勒泰地区":       "xin1_jiang1_a1_le4_tai4_di4_qu1",
	"阿坝藏族羌族自治州":   "si4_chuan1_a1_ba4_cang2_zu2_qiang1_zu2_zi4_zhi4_zhou1",
	"阿拉善盟":        "nei4_meng2_gu3_a1_la1_shan4_meng2",
	"阿拉尔":         "xin1_jiang1_a1_la1_er3",
	"阿里地区":        "xi1_cang2_a1_li3_di4_qu1",
	"陇南":          "gan1_su4_long3_nan2",
	"陵水黎族自治县":     "hai3_nan2_ling2_shui3_li2_zu2_zi4_zhi4_xian4",
	"随州":          "hu2_bei3_sui2_zhou1",
	"雅安":          "si4_chuan1_ya3_an1",
	"青岛":          "shan1_dong1_qing1_dao3",
	"鞍山":          "liao2_ning2_an1_shan1",
	"韶关":          "guang3_dong1_shao2_guan1",
	"香港":          "xianggang",
	"马鞍山":         "an1_hui1_ma3_an1_shan1",
	"驻马店":         "he2_nan2_zhu4_ma3_dian4",
	"鸡西":          "hei1_long2_jiang1_ji1_xi1",
	"鹤壁":          "he2_nan2_he4_bi4",
	"鹤岗":          "hei1_long2_jiang1_he4_gang3",
	"鹰潭":          "jiang1_xi1_ying1_tan2",
	"黄冈":          "hu2_bei3_huang2_gang1",
	"黄南藏族自治州":     "qing1_hai3_huang2_nan2_cang2_zu2_zi4_zhi4_zhou1",
	"黄山":          "an1_hui1_huang2_shan1",
	"黄石":          "hu2_bei3_huang2_shi2",
	"黑河":          "hei1_long2_jiang1_hei1_he2",
	"黔东南苗族侗族自治州":  "gui4_zhou1_qian2_dong1_nan2_miao2_zu2_tong1_zu2_zi4_zhi4_zhou1",
	"黔南布依族苗族自治州":  "gui4_zhou1_qian2_nan2_bu4_yi1_zu2_miao2_zu2_zi4_zhi4_zhou1",
	"黔西南布依族苗族自治州": "gui4_zhou1_qian2_xi1_nan2_bu4_yi1_zu2_miao2_zu2_zi4_zhi4_zhou1",
	"齐齐哈尔":        "hei1_long2_jiang1_qi2_qi2_ha1_er3",
	"龙岩":          "fu2_jian4_long2_yan2",
}
