package types

// Chart Type contains string representations of chart types.
const (
	ChartBar           = "bar"
	ChartBar3D         = "bar3D"
	ChartBoxPlot       = "boxplot"
	ChartCartesian3D   = "cartesian3D"
	ChartEffectScatter = "effectScatter"
	ChartFunnel        = "funnel"
	ChartGauge         = "gauge"
	ChartGeo           = "geo"
	ChartGraph         = "graph"
	ChartHeatMap       = "heatmap"
	ChartKline         = "candlestick"
	ChartLine          = "line"
	ChartLine3D        = "line3D"
	ChartLiquid        = "liquidFill"
	ChartMap           = "map"
	ChartParallel      = "parallel"
	ChartPie           = "pie"
	ChartRadar         = "radar"
	ChartSankey        = "sankey"
	ChartScatter       = "scatter"
	ChartScatter3D     = "scatter3D"
	ChartSurface3D     = "surface"
	ChartThemeRiver    = "themeRiver"
	ChartWordCloud     = "wordCloud"
	ChartTree          = "tree"
	ChartTreeMap       = "treemap"
	ChartSunburst      = "sunburst"
	ChartCustom        = "custom"
)
